%global cross_arch    arm
%global target        %{cross_arch}-linux-gnu
# cross gcc builds--with-float=hard
%global cross_triplet %{target}eabihf
%global cross_sysroot %{_prefix}/%{target}/sys-root
%global __provides_exclude_from ^%{cross_sysroot}
%global __requires_exclude_from ^%{cross_sysroot}
%global headerspath %{_prefix}/%{target}/include
# Debuginfo issues with s390x and ppc64
# But: I'm not sure the debuginfo generated here is useful anyways
%global debug_package %{nil}

%if %{cross_arch} == "arm"
  %define arm_type      %(echo %{cross_triplet} | sed 's/.*-\\([a-z]*\\)$/\\1/')
  %if %{arm_type} == "gnueabi"
    %define loader_suffix     %{nil}
    %define loader_version    3
    %define gnu_hdr_suffix    -soft
    %define lib_dir_name      lib
  %else
    %if %{arm_type} == "gnueabihf"
      %define loader_suffix   -armhf
      %define loader_version  3
      %define gnu_hdr_suffix  -hard
      %define lib_dir_name    lib
    %else
      %{error:Unsupported ARM processor type}
    %endif
  %endif
%else
  %if %{cross_arch} == "arm64"
    %define loader_suffix     -aarch64
    %define loader_version    1
    %define gnu_hdr_suffix    -lp64
    %define lib_dir_name      lib64
  %else
    %define loader_suffix     %{nil}
    %define loader_version    0
    %define gnu_hdr_suffix    %{nil}
    %define lib_dir_name      lib
  %endif
%endif

Name:		glibc-%{target}
Version:	2.27
Release:	4%{?dist}
Summary:	Cross Compiled GNU C Library targeted at %{target}
Group:		Development/Languages
License:	LGPLv2+ and BSD and MIT
URL:		http://www.gnu.org/software/libc/
Source0:	ftp://ftp.gnu.org/gnu/glibc/glibc-%{version}.tar.xz
BuildRequires:	gcc
BuildRequires:	gcc-%{target}, perl-interpreter, bison
BuildRequires:	kernel-cross-headers
Requires:	kernel-cross-headers
Provides:	glibc-%{target}-devel = %{version}-%{release}
Obsoletes:	glibc-%{target}-devel < 2.26-2

%description
This is a Cross Compiled version of the GNU C Library, which can be used to
compile and link binaries for the %{target} platform, instead of for the
native platform.

%prep
%autosetup -p1 -n glibc-%{version}

# Convert files to utf8
# for i in glibc-%{version}/ChangeLog.*; do
# 	iconv -f iso8859-1 -t utf8 $i -o $i.utf8
# 	touch -r $i $i.utf8
#	mv $i.utf8 $i
# done

%build
mkdir -p %{_builddir}/build-%{target}-glibc
cd %{_builddir}/build-%{target}-glibc
BUILD_CC=%{_bindir}/gcc \
CC=%{_bindir}/%{target}-gcc \
CXX=%{_bindir}/%{target}-g++ \
AR=%{_bindir}/%{target}-ar \
RANLIB=%{_bindir}/%{target}-ranlib \
../glibc-%{version}/configure \
  --prefix=%{_prefix} \
  --host=%{cross_triplet} \
  --build=%{_target_platform} \
  --enable-kernel=2.6.32 \
  --enable-shared \
  --enable-add-ons \
  --enable-multi-arch \
  --enable-obsolete-rpc \
  --enable-obsolete-nsl \
  --enable-stack-protector=strong \
  --enable-tunables \
  --disable-profile \
  --with-headers=%{headerspath} \
  --with-tls \
  --with-__thread \
  --without-cvs \
  --without-gd

make %{?_smp_mflags}

# generate stubs.h
for i in io math misc posix stdlib streams; do
  make -C ../glibc-%{version}/$i objdir=`pwd` stubs
  cat $i/stubs >> subdir-stubs.h
done

sed '/^@/d' < ../glibc-%{version}/include/stubs-prologue.h > stubs.h
sort subdir-stubs.h >> stubs.h

%install
cd %{_builddir}/build-%{target}-glibc
make %{?_smp_mflags} install_root=%{buildroot}%{cross_sysroot} install
rm -rf %{buildroot}%{cross_sysroot}/usr/share/man
rm -rf %{buildroot}%{cross_sysroot}/usr/share/info
rm -rf %{buildroot}%{cross_sysroot}/usr/share/locale

if [ -d "%{buildroot}/usr/lib/.buildid" ]; then
	rm -rf %{buildroot}/usr/lib/.buildid
fi
# Don't any static archive - based on Fedora Project cross-gcc.spec
%define __ar_no_strip $RPM_BUILD_DIR/glibc-%{version}/ar-no-strip
cat > %{__ar_no_strip} << EOF
#!/bin/sh
f=\$2
case \$(basename \$f) in
    *.a)
        ;;
    *)
        %{__strip} \$@
        ;;
esac
EOF
chmod +x %{__ar_no_strip}
%undefine __strip
%define __strip %{__ar_no_strip}

%files
%license COPYING COPYING.LIB LICENSES
%doc ChangeLog
%doc ChangeLog.old/ChangeLog.1 ChangeLog.old/ChangeLog.2 ChangeLog.old/ChangeLog.3 ChangeLog.old/ChangeLog.4 ChangeLog.old/ChangeLog.5
%doc ChangeLog.old/ChangeLog.6 ChangeLog.old/ChangeLog.7 ChangeLog.old/ChangeLog.8 ChangeLog.old/ChangeLog.9 ChangeLog.old/ChangeLog.10
%doc ChangeLog.old/ChangeLog.11 ChangeLog.old/ChangeLog.12 ChangeLog.old/ChangeLog.13 ChangeLog.old/ChangeLog.14 ChangeLog.old/ChangeLog.15
%doc ChangeLog.old/ChangeLog.16 ChangeLog.old/ChangeLog.17 ChangeLog.old/ChangeLog.18
%doc NEWS README
%doc manual/README.pretty-printers manual/README.tunables
%{cross_sysroot}/usr/include/_G_config.h
%{cross_sysroot}/usr/include/a.out.h
%{cross_sysroot}/usr/include/aio.h
%{cross_sysroot}/usr/include/aliases.h
%{cross_sysroot}/usr/include/alloca.h
%{cross_sysroot}/usr/include/ar.h
%{cross_sysroot}/usr/include/argp.h
%{cross_sysroot}/usr/include/argz.h
%dir %{cross_sysroot}/usr/include/arpa
%{cross_sysroot}/usr/include/arpa/ftp.h
%{cross_sysroot}/usr/include/arpa/inet.h
%{cross_sysroot}/usr/include/arpa/nameser.h
%{cross_sysroot}/usr/include/arpa/nameser_compat.h
%{cross_sysroot}/usr/include/arpa/telnet.h
%{cross_sysroot}/usr/include/arpa/tftp.h
%{cross_sysroot}/usr/include/assert.h
%{cross_sysroot}/usr/include/bits
%{cross_sysroot}/usr/include/byteswap.h
%{cross_sysroot}/usr/include/complex.h
%{cross_sysroot}/usr/include/cpio.h
%{cross_sysroot}/usr/include/crypt.h
%{cross_sysroot}/usr/include/ctype.h
%{cross_sysroot}/usr/include/dirent.h
%{cross_sysroot}/usr/include/dlfcn.h
%{cross_sysroot}/usr/include/elf.h
%{cross_sysroot}/usr/include/endian.h
%{cross_sysroot}/usr/include/envz.h
%{cross_sysroot}/usr/include/err.h
%{cross_sysroot}/usr/include/errno.h
%{cross_sysroot}/usr/include/error.h
%{cross_sysroot}/usr/include/execinfo.h
%{cross_sysroot}/usr/include/fcntl.h
%{cross_sysroot}/usr/include/features.h
%{cross_sysroot}/usr/include/fenv.h
%{cross_sysroot}/usr/include/fmtmsg.h
%{cross_sysroot}/usr/include/fnmatch.h
%{cross_sysroot}/usr/include/fpu_control.h
%{cross_sysroot}/usr/include/fstab.h
%{cross_sysroot}/usr/include/fts.h
%{cross_sysroot}/usr/include/ftw.h
%{cross_sysroot}/usr/include/gconv.h
%{cross_sysroot}/usr/include/getopt.h
%{cross_sysroot}/usr/include/glob.h
%{cross_sysroot}/usr/include/gnu-versions.h
%dir %{cross_sysroot}/usr/include/gnu
%{cross_sysroot}/usr/include/gnu/lib-names.h
%{cross_sysroot}/usr/include/gnu/libc-version.h
%{cross_sysroot}/usr/include/gnu/stubs.h
%{cross_sysroot}/usr/include/grp.h
%{cross_sysroot}/usr/include/gshadow.h
%{cross_sysroot}/usr/include/iconv.h
%{cross_sysroot}/usr/include/ieee754.h
%{cross_sysroot}/usr/include/ifaddrs.h
%{cross_sysroot}/usr/include/inttypes.h
%{cross_sysroot}/usr/include/langinfo.h
%{cross_sysroot}/usr/include/lastlog.h
%{cross_sysroot}/usr/include/libgen.h
%{cross_sysroot}/usr/include/libintl.h
%{cross_sysroot}/usr/include/libio.h
%{cross_sysroot}/usr/include/limits.h
%{cross_sysroot}/usr/include/link.h
%{cross_sysroot}/usr/include/locale.h
%{cross_sysroot}/usr/include/malloc.h
%{cross_sysroot}/usr/include/math.h
%{cross_sysroot}/usr/include/mcheck.h
%{cross_sysroot}/usr/include/memory.h
%{cross_sysroot}/usr/include/mntent.h
%{cross_sysroot}/usr/include/monetary.h
%{cross_sysroot}/usr/include/mqueue.h
%dir %{cross_sysroot}/usr/include/net
%{cross_sysroot}/usr/include/net/ethernet.h
%{cross_sysroot}/usr/include/net/if.h
%{cross_sysroot}/usr/include/net/if_arp.h
%{cross_sysroot}/usr/include/net/if_packet.h
%{cross_sysroot}/usr/include/net/if_ppp.h
%{cross_sysroot}/usr/include/net/if_shaper.h
%{cross_sysroot}/usr/include/net/if_slip.h
%{cross_sysroot}/usr/include/net/ppp-comp.h
%{cross_sysroot}/usr/include/net/ppp_defs.h
%{cross_sysroot}/usr/include/net/route.h
%dir %{cross_sysroot}/usr/include/netash
%{cross_sysroot}/usr/include/netash/ash.h
%dir %{cross_sysroot}/usr/include/netatalk
%{cross_sysroot}/usr/include/netatalk/at.h
%dir %{cross_sysroot}/usr/include/netax25
%{cross_sysroot}/usr/include/netax25/ax25.h
%{cross_sysroot}/usr/include/netdb.h
%dir %{cross_sysroot}/usr/include/neteconet
%{cross_sysroot}/usr/include/neteconet/ec.h
%dir %{cross_sysroot}/usr/include/netinet
%{cross_sysroot}/usr/include/netinet/ether.h
%{cross_sysroot}/usr/include/netinet/icmp6.h
%{cross_sysroot}/usr/include/netinet/if_ether.h
%{cross_sysroot}/usr/include/netinet/if_fddi.h
%{cross_sysroot}/usr/include/netinet/if_tr.h
%{cross_sysroot}/usr/include/netinet/igmp.h
%{cross_sysroot}/usr/include/netinet/in.h
%{cross_sysroot}/usr/include/netinet/in_systm.h
%{cross_sysroot}/usr/include/netinet/ip.h
%{cross_sysroot}/usr/include/netinet/ip6.h
%{cross_sysroot}/usr/include/netinet/ip_icmp.h
%{cross_sysroot}/usr/include/netinet/tcp.h
%{cross_sysroot}/usr/include/netinet/udp.h
%dir %{cross_sysroot}/usr/include/netipx
%{cross_sysroot}/usr/include/netipx/ipx.h
%dir %{cross_sysroot}/usr/include/netiucv
%{cross_sysroot}/usr/include/netiucv/iucv.h
%dir %{cross_sysroot}/usr/include/netpacket
%{cross_sysroot}/usr/include/netpacket/packet.h
%dir %{cross_sysroot}/usr/include/netrom
%{cross_sysroot}/usr/include/netrom/netrom.h
%dir %{cross_sysroot}/usr/include/netrose
%{cross_sysroot}/usr/include/netrose/rose.h
%dir %{cross_sysroot}/usr/include/nfs
%{cross_sysroot}/usr/include/nfs/nfs.h
%{cross_sysroot}/usr/include/nl_types.h
%{cross_sysroot}/usr/include/nss.h
%{cross_sysroot}/usr/include/obstack.h
%{cross_sysroot}/usr/include/paths.h
%{cross_sysroot}/usr/include/poll.h
%{cross_sysroot}/usr/include/printf.h
%{cross_sysroot}/usr/include/proc_service.h
%dir %{cross_sysroot}/usr/include/protocols
%{cross_sysroot}/usr/include/protocols/routed.h
%{cross_sysroot}/usr/include/protocols/rwhod.h
%{cross_sysroot}/usr/include/protocols/talkd.h
%{cross_sysroot}/usr/include/protocols/timed.h
%{cross_sysroot}/usr/include/pthread.h
%{cross_sysroot}/usr/include/pty.h
%{cross_sysroot}/usr/include/pwd.h
%{cross_sysroot}/usr/include/re_comp.h
%{cross_sysroot}/usr/include/regex.h
%{cross_sysroot}/usr/include/regexp.h
%{cross_sysroot}/usr/include/resolv.h
%{cross_sysroot}/usr/include/rpc
%{cross_sysroot}/usr/include/rpcsvc
%{cross_sysroot}/usr/include/sched.h
%{cross_sysroot}/usr/include/scsi
%{cross_sysroot}/usr/include/search.h
%{cross_sysroot}/usr/include/semaphore.h
%{cross_sysroot}/usr/include/setjmp.h
%{cross_sysroot}/usr/include/sgtty.h
%{cross_sysroot}/usr/include/shadow.h
%{cross_sysroot}/usr/include/signal.h
%{cross_sysroot}/usr/include/spawn.h
%{cross_sysroot}/usr/include/stab.h
%{cross_sysroot}/usr/include/stdc-predef.h
%{cross_sysroot}/usr/include/stdint.h
%{cross_sysroot}/usr/include/stdio.h
%{cross_sysroot}/usr/include/stdio_ext.h
%{cross_sysroot}/usr/include/stdlib.h
%{cross_sysroot}/usr/include/string.h
%{cross_sysroot}/usr/include/strings.h
%{cross_sysroot}/usr/include/stropts.h
%dir %{cross_sysroot}/usr/include/sys
%{cross_sysroot}/usr/include/sys/acct.h
%{cross_sysroot}/usr/include/sys/auxv.h
%{cross_sysroot}/usr/include/sys/bitypes.h
%{cross_sysroot}/usr/include/sys/cdefs.h
%{cross_sysroot}/usr/include/sys/dir.h
%{cross_sysroot}/usr/include/sys/elf.h
%{cross_sysroot}/usr/include/sys/epoll.h
%{cross_sysroot}/usr/include/sys/errno.h
%{cross_sysroot}/usr/include/sys/eventfd.h
%{cross_sysroot}/usr/include/sys/fanotify.h
%{cross_sysroot}/usr/include/sys/fcntl.h
%{cross_sysroot}/usr/include/sys/file.h
%{cross_sysroot}/usr/include/sys/fsuid.h
%{cross_sysroot}/usr/include/sys/gmon.h
%{cross_sysroot}/usr/include/sys/gmon_out.h
%{cross_sysroot}/usr/include/sys/inotify.h
%if %{cross_arch} == "arm"
%{cross_sysroot}/usr/include/sys/io.h
%endif
%{cross_sysroot}/usr/include/sys/ioctl.h
%{cross_sysroot}/usr/include/sys/ipc.h
%{cross_sysroot}/usr/include/sys/kd.h
%{cross_sysroot}/usr/include/sys/klog.h
%{cross_sysroot}/usr/include/sys/mman.h
%{cross_sysroot}/usr/include/sys/mount.h
%{cross_sysroot}/usr/include/sys/msg.h
%{cross_sysroot}/usr/include/sys/mtio.h
%{cross_sysroot}/usr/include/sys/param.h
%{cross_sysroot}/usr/include/sys/pci.h
%{cross_sysroot}/usr/include/sys/personality.h
%{cross_sysroot}/usr/include/sys/poll.h
%{cross_sysroot}/usr/include/sys/prctl.h
%{cross_sysroot}/usr/include/sys/procfs.h
%{cross_sysroot}/usr/include/sys/profil.h
%{cross_sysroot}/usr/include/sys/ptrace.h
%{cross_sysroot}/usr/include/sys/queue.h
%{cross_sysroot}/usr/include/sys/quota.h
%{cross_sysroot}/usr/include/sys/random.h
%{cross_sysroot}/usr/include/sys/raw.h
%{cross_sysroot}/usr/include/sys/reboot.h
%{cross_sysroot}/usr/include/sys/resource.h
%{cross_sysroot}/usr/include/sys/select.h
%{cross_sysroot}/usr/include/sys/sem.h
%{cross_sysroot}/usr/include/sys/sendfile.h
%{cross_sysroot}/usr/include/sys/shm.h
%{cross_sysroot}/usr/include/sys/signal.h
%{cross_sysroot}/usr/include/sys/signalfd.h
%{cross_sysroot}/usr/include/sys/socket.h
%{cross_sysroot}/usr/include/sys/socketvar.h
%{cross_sysroot}/usr/include/sys/soundcard.h
%{cross_sysroot}/usr/include/sys/stat.h
%{cross_sysroot}/usr/include/sys/statfs.h
%{cross_sysroot}/usr/include/sys/statvfs.h
%{cross_sysroot}/usr/include/sys/stropts.h
%{cross_sysroot}/usr/include/sys/swap.h
%{cross_sysroot}/usr/include/sys/syscall.h
%{cross_sysroot}/usr/include/sys/sysctl.h
%{cross_sysroot}/usr/include/sys/sysinfo.h
%{cross_sysroot}/usr/include/sys/syslog.h
%{cross_sysroot}/usr/include/sys/sysmacros.h
%{cross_sysroot}/usr/include/sys/termios.h
%{cross_sysroot}/usr/include/sys/time.h
%{cross_sysroot}/usr/include/sys/timeb.h
%{cross_sysroot}/usr/include/sys/timerfd.h
%{cross_sysroot}/usr/include/sys/times.h
%{cross_sysroot}/usr/include/sys/timex.h
%{cross_sysroot}/usr/include/sys/ttychars.h
%{cross_sysroot}/usr/include/sys/ttydefaults.h
%{cross_sysroot}/usr/include/sys/types.h
%{cross_sysroot}/usr/include/sys/ucontext.h
%{cross_sysroot}/usr/include/sys/uio.h
%{cross_sysroot}/usr/include/sys/un.h
%{cross_sysroot}/usr/include/sys/unistd.h
%{cross_sysroot}/usr/include/sys/user.h
%{cross_sysroot}/usr/include/sys/ustat.h
%{cross_sysroot}/usr/include/sys/utsname.h
%{cross_sysroot}/usr/include/sys/vfs.h
%{cross_sysroot}/usr/include/sys/vlimit.h
%{cross_sysroot}/usr/include/sys/vt.h
%{cross_sysroot}/usr/include/sys/vtimes.h
%{cross_sysroot}/usr/include/sys/wait.h
%{cross_sysroot}/usr/include/sys/xattr.h
%{cross_sysroot}/usr/include/syscall.h
%{cross_sysroot}/usr/include/sysexits.h
%{cross_sysroot}/usr/include/syslog.h
%{cross_sysroot}/usr/include/tar.h
%{cross_sysroot}/usr/include/termio.h
%{cross_sysroot}/usr/include/termios.h
%{cross_sysroot}/usr/include/tgmath.h
%{cross_sysroot}/usr/include/thread_db.h
%{cross_sysroot}/usr/include/time.h
%{cross_sysroot}/usr/include/ttyent.h
%{cross_sysroot}/usr/include/uchar.h
%{cross_sysroot}/usr/include/ucontext.h
%{cross_sysroot}/usr/include/ulimit.h
%{cross_sysroot}/usr/include/unistd.h
%{cross_sysroot}/usr/include/ustat.h
%{cross_sysroot}/usr/include/utime.h
%{cross_sysroot}/usr/include/utmp.h
%{cross_sysroot}/usr/include/utmpx.h
%{cross_sysroot}/usr/include/values.h
%{cross_sysroot}/usr/include/wait.h
%{cross_sysroot}/usr/include/wchar.h
%{cross_sysroot}/usr/include/wctype.h
%{cross_sysroot}/usr/include/wordexp.h
%{cross_sysroot}/usr/%{lib_dir_name}/crt1.o
%{cross_sysroot}/usr/%{lib_dir_name}/crti.o
%{cross_sysroot}/usr/%{lib_dir_name}/crtn.o
%{cross_sysroot}/usr/%{lib_dir_name}/libc.so
%{cross_sysroot}/etc/rpc
%if %{cross_arch} == "arm64"
%{cross_sysroot}/lib/ld-linux%{loader_suffix}.so.%{loader_version}
%else
%{cross_sysroot}/%{lib_dir_name}/ld-linux%{loader_suffix}.so.%{loader_version}
%endif
%{cross_sysroot}/%{lib_dir_name}/ld-%{version}.so
%{cross_sysroot}/%{lib_dir_name}/libBrokenLocale-%{version}.so
%{cross_sysroot}/%{lib_dir_name}/libBrokenLocale.so.1
%{cross_sysroot}/%{lib_dir_name}/libSegFault.so
%{cross_sysroot}/%{lib_dir_name}/libanl-%{version}.so
%{cross_sysroot}/%{lib_dir_name}/libanl.so.1
%{cross_sysroot}/%{lib_dir_name}/libc-%{version}.so
%{cross_sysroot}/%{lib_dir_name}/libc.so.6
%{cross_sysroot}/%{lib_dir_name}/libcidn-%{version}.so
%{cross_sysroot}/%{lib_dir_name}/libcidn.so.1
%{cross_sysroot}/%{lib_dir_name}/libcrypt-%{version}.so
%{cross_sysroot}/%{lib_dir_name}/libcrypt.so.1
%{cross_sysroot}/%{lib_dir_name}/libdl-%{version}.so
%{cross_sysroot}/%{lib_dir_name}/libdl.so.2
%{cross_sysroot}/%{lib_dir_name}/libm-%{version}.so
%{cross_sysroot}/%{lib_dir_name}/libm.so.6
%{cross_sysroot}/%{lib_dir_name}/libmemusage.so
%{cross_sysroot}/%{lib_dir_name}/libnsl-%{version}.so
%{cross_sysroot}/%{lib_dir_name}/libnsl.so.1
%{cross_sysroot}/%{lib_dir_name}/libnss_compat-%{version}.so
%{cross_sysroot}/%{lib_dir_name}/libnss_compat.so.2
%{cross_sysroot}/%{lib_dir_name}/libnss_db-%{version}.so
%{cross_sysroot}/%{lib_dir_name}/libnss_db.so.2
%{cross_sysroot}/%{lib_dir_name}/libnss_dns-%{version}.so
%{cross_sysroot}/%{lib_dir_name}/libnss_dns.so.2
%{cross_sysroot}/%{lib_dir_name}/libnss_files-%{version}.so
%{cross_sysroot}/%{lib_dir_name}/libnss_files.so.2
%{cross_sysroot}/%{lib_dir_name}/libnss_hesiod-%{version}.so
%{cross_sysroot}/%{lib_dir_name}/libnss_hesiod.so.2
%{cross_sysroot}/%{lib_dir_name}/libnss_nis-%{version}.so
%{cross_sysroot}/%{lib_dir_name}/libnss_nis.so.2
%{cross_sysroot}/%{lib_dir_name}/libnss_nisplus-%{version}.so
%{cross_sysroot}/%{lib_dir_name}/libnss_nisplus.so.2
%{cross_sysroot}/%{lib_dir_name}/libpcprofile.so
%{cross_sysroot}/%{lib_dir_name}/libpthread-%{version}.so
%{cross_sysroot}/%{lib_dir_name}/libpthread.so.0
%{cross_sysroot}/%{lib_dir_name}/libresolv-%{version}.so
%{cross_sysroot}/%{lib_dir_name}/libresolv.so.2
%{cross_sysroot}/%{lib_dir_name}/librt-%{version}.so
%{cross_sysroot}/%{lib_dir_name}/librt.so.1
%{cross_sysroot}/%{lib_dir_name}/libthread_db-1.0.so
%{cross_sysroot}/%{lib_dir_name}/libthread_db.so.1
%{cross_sysroot}/%{lib_dir_name}/libutil-%{version}.so
%{cross_sysroot}/%{lib_dir_name}/libutil.so.1
%{cross_sysroot}/sbin/ldconfig
%{cross_sysroot}/sbin/sln
%{cross_sysroot}/usr/bin/catchsegv
%{cross_sysroot}/usr/bin/gencat
%{cross_sysroot}/usr/bin/getconf
%{cross_sysroot}/usr/bin/getent
%{cross_sysroot}/usr/bin/iconv
%{cross_sysroot}/usr/bin/ldd
%{cross_sysroot}/usr/bin/locale
%{cross_sysroot}/usr/bin/localedef
%{cross_sysroot}/usr/bin/makedb
%{cross_sysroot}/usr/bin/mtrace
%{cross_sysroot}/usr/bin/pcprofiledump
%{cross_sysroot}/usr/bin/pldd
%{cross_sysroot}/usr/bin/rpcgen
%{cross_sysroot}/usr/bin/sotruss
%{cross_sysroot}/usr/bin/sprof
%{cross_sysroot}/usr/bin/tzselect
%{cross_sysroot}/usr/bin/xtrace
%{cross_sysroot}/usr/include/gnu/lib-names%{gnu_hdr_suffix}.h
%{cross_sysroot}/usr/include/gnu/stubs%{gnu_hdr_suffix}.h
%{cross_sysroot}/usr/%{lib_dir_name}/?crt1.o
%{cross_sysroot}/usr/%{lib_dir_name}/audit
%{cross_sysroot}/usr/%{lib_dir_name}/gconv
%{cross_sysroot}/usr/%{lib_dir_name}/libBrokenLocale.a
%{cross_sysroot}/usr/%{lib_dir_name}/libBrokenLocale.so
%{cross_sysroot}/usr/%{lib_dir_name}/libanl.a
%{cross_sysroot}/usr/%{lib_dir_name}/libanl.so
%{cross_sysroot}/usr/%{lib_dir_name}/libc.a
%{cross_sysroot}/usr/%{lib_dir_name}/libc_nonshared.a
%{cross_sysroot}/usr/%{lib_dir_name}/libcidn.so
%{cross_sysroot}/usr/%{lib_dir_name}/libcrypt.a
%{cross_sysroot}/usr/%{lib_dir_name}/libcrypt.so
%{cross_sysroot}/usr/%{lib_dir_name}/libdl.a
%{cross_sysroot}/usr/%{lib_dir_name}/libdl.so
%{cross_sysroot}/usr/%{lib_dir_name}/libg.a
# %%{cross_sysroot}/usr/%{lib_dir_name}/libieee.a
%{cross_sysroot}/usr/%{lib_dir_name}/libm.a
%{cross_sysroot}/usr/%{lib_dir_name}/libm.so
%{cross_sysroot}/usr/%{lib_dir_name}/libmcheck.a
%{cross_sysroot}/usr/%{lib_dir_name}/libnsl.a
%{cross_sysroot}/usr/%{lib_dir_name}/libnsl.so
%{cross_sysroot}/usr/%{lib_dir_name}/libnss_compat.so
%{cross_sysroot}/usr/%{lib_dir_name}/libnss_db.so
%{cross_sysroot}/usr/%{lib_dir_name}/libnss_dns.so
%{cross_sysroot}/usr/%{lib_dir_name}/libnss_files.so
%{cross_sysroot}/usr/%{lib_dir_name}/libnss_hesiod.so
%{cross_sysroot}/usr/%{lib_dir_name}/libnss_nis.so
%{cross_sysroot}/usr/%{lib_dir_name}/libnss_nisplus.so
%{cross_sysroot}/usr/%{lib_dir_name}/libpthread.a
%{cross_sysroot}/usr/%{lib_dir_name}/libpthread.so
%{cross_sysroot}/usr/%{lib_dir_name}/libpthread_nonshared.a
%{cross_sysroot}/usr/%{lib_dir_name}/libresolv.a
%{cross_sysroot}/usr/%{lib_dir_name}/libresolv.so
%{cross_sysroot}/usr/%{lib_dir_name}/librpcsvc.a
%{cross_sysroot}/usr/%{lib_dir_name}/librt.a
%{cross_sysroot}/usr/%{lib_dir_name}/librt.so
%{cross_sysroot}/usr/%{lib_dir_name}/libthread_db.so
%{cross_sysroot}/usr/%{lib_dir_name}/libutil.a
%{cross_sysroot}/usr/%{lib_dir_name}/libutil.so
%dir %{cross_sysroot}/usr/libexec/getconf
%if %{cross_arch} == "arm"
%{cross_sysroot}/usr/libexec/getconf/POSIX_V6_ILP32_OFF32
%{cross_sysroot}/usr/libexec/getconf/POSIX_V6_ILP32_OFFBIG
%{cross_sysroot}/usr/libexec/getconf/POSIX_V7_ILP32_OFF32
%{cross_sysroot}/usr/libexec/getconf/POSIX_V7_ILP32_OFFBIG
%{cross_sysroot}/usr/libexec/getconf/XBS5_ILP32_OFF32
%{cross_sysroot}/usr/libexec/getconf/XBS5_ILP32_OFFBIG
%else
%if %{cross_arch} == "arm64"
%{cross_sysroot}/usr/libexec/getconf/POSIX_V6_LP64_OFF64
%{cross_sysroot}/usr/libexec/getconf/POSIX_V7_LP64_OFF64
%{cross_sysroot}/usr/libexec/getconf/XBS5_LP64_OFF64
%endif
%endif
%{cross_sysroot}/usr/sbin/iconvconfig
%{cross_sysroot}/usr/sbin/nscd
%{cross_sysroot}/usr/sbin/zdump
%{cross_sysroot}/usr/sbin/zic
%dir %{cross_sysroot}/usr/share/i18n
%{cross_sysroot}/usr/share/i18n/charmaps
%{cross_sysroot}/usr/share/i18n/locales
%{cross_sysroot}/var/db/Makefile

%changelog
* Mon Jul 23 2018 Tom Callaway <spot@fedoraproject.org> - 2.27-4
- add BuildRequires: gcc

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.27-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.27-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Fri Feb  2 2018 Tom Callaway <spot@fedoraproject.org> - 2.27-1
- update to 2.27

* Thu Jan 18 2018 Tom Callaway <spot@fedoraproject.org> - 2.26-4
- apply patch from upstream to resolve CVE-2018-1000001

* Fri Nov 10 2017 Tom Callaway <spot@fedoraproject.org> - 2.26-3
- disable debuginfo generation

* Thu Nov  9 2017 Tom Callaway <spot@fedoraproject.org> - 2.26-2
- rework package significantly to "just work" with the rest of the cross- toolchain

* Tue Aug  8 2017 Tom Callaway <spot@fedoraproject.org> - 2.26-1
- update to 2.26

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.25-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Wed Feb  8 2017 Tom Callaway <spot@fedoraproject.org> - 2.25-1
- update to 2.25

* Mon Oct 10 2016 Tom Callaway <spot@fedoraproject.org> - 2.24-2
- apply upstream fix for CVE-2016-6323

* Mon Aug  8 2016 Tom Callaway <spot@fedoraproject.org> - 2.24-1
- update to 2.24

* Mon Jun  6 2016 Tom Callaway <spot@fedoraproject.org> - 2.23-4
- drop Changelogs (not useful in a cross-compile package)
- own COPYING as license
- own /usr/arm-linux-gnu
- document how to make arm-kernel-headers tarball (f23 and older)
- fix license tag to be pedantic correct vs inherited correct

* Thu May 19 2016 Tom Callaway <spot@fedoraproject.org> - 2.23-3
- fix compile with gcc 6.1 (thanks to Yvan Roux and Dominik 'Rathann' Mierzejewski)

* Tue Apr 26 2016 Tom Callaway <spot@fedoraproject.org> - 2.23-2
- no locales
- no infodir (if we want this later, add BuildRequires: texinfo)

* Fri Feb 26 2016 Tom Callaway <spot@fedoraproject.org> - 2.23-1
- modernize spec file
- update to 2.23

* Mon Feb  8 2016 Tom Callaway <spot@fedoraproject.org> - 2.22-2
- package kernel headers in this too (for now)

* Wed Feb  3 2016 Tom Callaway <spot@fedoraproject.org> - 2.22-1
- HELP ME I AM IN HELL
